@@ -15,34 +15,29 @@ class VideoInfoExtractor : public QObject
 
     Q_PROPERTY(QString videoId READ videoId WRITE setVideoId NOTIFY videoIdChanged)
 
-    Q_PROPERTY(QUrl audioUrl READ audioUrl NOTIFY audioUrlChanged)
-    Q_PROPERTY(QString title READ title NOTIFY titleChanged)
-    Q_PROPERTY(QString artist READ artist NOTIFY artistChanged) // may be empty if it is a video
-    Q_PROPERTY(QString channel READ channel NOTIFY channelChanged)
-    Q_PROPERTY(QString thumbnail READ thumbnail NOTIFY thumbnailChanged)
-    Q_PROPERTY(bool loading READ loading WRITE setLoading NOTIFY loadingChanged)
+    Q_PROPERTY(QUrl audioUrl READ audioUrl NOTIFY songChanged)
+    Q_PROPERTY(QString title READ title NOTIFY songChanged)
+    Q_PROPERTY(QString artist READ artist NOTIFY songChanged) // may be empty if it is a video
+    Q_PROPERTY(QString channel READ channel NOTIFY songChanged)
+    Q_PROPERTY(QString thumbnail READ thumbnail NOTIFY songChanged)
+    Q_PROPERTY(bool loading READ loading WRITE setLoading NOTIFY songChanged)
 
 public:
     explicit VideoInfoExtractor(QObject *parent = nullptr);
 
     QUrl audioUrl() const;
-    Q_SIGNAL void audioUrlChanged();
 
     QString videoId() const;
     void setVideoId(const QString &videoId);
     Q_SIGNAL void videoIdChanged();
 
     QString title() const;
-    Q_SIGNAL void titleChanged();
-    
+
     QString artist() const;
-    Q_SIGNAL void artistChanged();
-    
+
     QString channel() const;
-    Q_SIGNAL void channelChanged();
 
     QString thumbnail() const;
-    Q_SIGNAL void thumbnailChanged();
 
     bool loading() const;
     void setLoading(bool loading);
